@@ -353,7 +353,7 @@ bool CsValaImportBase::parseStmt()
         keyword = advance();
     }
 
-    // At this point, we expect `keyword' to be a type name
+    // At this point, we expect `keyword` to be a type name
     // (of a member of class or interface, or return type
     // of an operation.) Up next is the name of the attribute
     // or operation.
@@ -477,7 +477,7 @@ bool CsValaImportBase::parseStmt()
                     break;
                 }
             } else {
-                name += nextToken;  // add possible array dimensions to `name'
+                name += nextToken;  // add possible array dimensions to `name`
             }
             nextToken = advance();
             if (nextToken.isEmpty()) {
